@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -28,7 +28,7 @@
 
 using namespace KChart;
 
-class BackgroundAttributes::Private
+class Q_DECL_HIDDEN BackgroundAttributes::Private
 {
     friend class KChart::BackgroundAttributes;
 public:
