@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -38,7 +38,7 @@
 
 namespace KChart {
   
-class RadarCoordinatePlane::Private : public PolarCoordinatePlane::Private
+class Q_DECL_HIDDEN RadarCoordinatePlane::Private : public PolarCoordinatePlane::Private
 {
     friend class RadarCoordinatePlane;
 public:
@@ -47,7 +47,7 @@ public:
     virtual ~Private() { }
     TextAttributes textAttributes;
     
-    virtual void initialize()
+    void initialize() Q_DECL_OVERRIDE
     {
         grid = new RadarGrid();
     }
